/* -*- C++ -*- Time-stamp: <19 Nov 00 19:26:07 Michael Bischoff> */

/*****************************************************************************/
/*									     */
/*									     */
/*	QMatchIt version 1.0 -- file field.h				     */
/*									     */
/*	Include file for the field base class of QMatchIt		     */
/*	written by Michael Bischoff (Michael.Bischoff@gmx.net)		     */
/*	November-2000							     */
/*	see COPYRIGHT.qmatchit for Copyright details			     */
/*									     */
/*									     */
/*****************************************************************************/

#ifndef FIELD_H
#define FIELD_H

class fieldGraphics;		// superclass of QCanvasSprite

class field {
    virtual void init(int x = 0, int y = 0, int a_subtype = 0);	// part of contructor

protected:
    fieldGraphics *gr;		// ptr to QCanvasItem
    int subtype;		// type of box for rtti == RTTI_BOX, type of magnet etc...
    int ctr;
    int state;			// 0 = basic, 1 = being destructed etc...

public:
    static void advance_all();
    static const int state_normal = 0;
    static const int state_anim =  1;
    static const int state_dead = 99;
    int idle_timer;		// counts ticks this object is in this position
    static field *newField(int ascii, int x, int y);	// create new field, in fields.cpp
    virtual ~field();		// TODO: virtual not needed, but warning by g++
    virtual bool feelsGravity() const { return false; }
    virtual bool feelsMagnets() const { return false; }
    void startDestruction();	// set state to 1 and animate it
    void stopDestruction();	// set state to 0 and stop animation
    int getSubtype()		const { return subtype; }
    void setState(int a_state);
    bool stateIs(int a_state)	const { return state == a_state; }
    void setXY(int x, int y)	const;			// only for game class
    virtual int ascii()		const { return rtti(); }	// only for game class
    virtual double getZ()	const { return 1.0; }		// default Z value for sprites
    virtual int rtti()		const = 0;			// return type of this field
    virtual int baseFrame()	const = 0;			// frame for this field (initial)
    virtual int currentFrame();		// frame for this field (current)
    virtual bool isAnimated()   const { return false; }
    virtual bool isSelectable() const { return false; }

};
#endif
